#include <stdio.h>
#include <assert.h>
#include <string.h>
#include <inttypes.h>
#include <algorithm>
#include <vector>
#include <string>

const int N = 1<<17;

struct node {
    int sum;
    bool need_push;
    int to_push;
    node() : sum(0), need_push(false), to_push(0) {};
} sgt[2*N];

void add_push(int t, int l, int r, int val) {
    sgt[t].sum = (r-l)*val;
    sgt[t].need_push = true;
    sgt[t].to_push = val;
}

void push(int t, int l, int r) {
    if (!sgt[t].need_push)
        return;
    sgt[t].need_push = false;
    if (r - l > 1) {
        int mid = (l+r)/2;
        add_push(t*2 + 1, l, mid, sgt[t].to_push);
        add_push(t*2 + 2, mid, r, sgt[t].to_push);
    }
}

void seg_set_val(int t, int l, int r, int ll, int rr, int val) {
    push(t, l, r);
    if (ll <= l && r <= rr) {
        add_push(t, l, r, val);
        return;
    }
    int mid = (l+r)/2;
    if (ll < mid)
        seg_set_val(t*2 + 1, l, mid, ll, rr, val);
    if (mid < rr)
        seg_set_val(t*2 + 2, mid, r, ll, rr, val);
    sgt[t].sum = sgt[t*2 + 1].sum + sgt[t*2 + 2].sum;
}

void set_val(int t, int l, int r, int i, int val) {
    push(t, l, r);
    if (r - l == 1) {
        assert(i == l);
        sgt[t].sum = val;
    } else {
        int mid = (l+r)/2;
        if (i < mid)
            set_val(t*2 + 1, l, mid, i, val);
        else
            set_val(t*2 + 2, mid, r, i, val);
        sgt[t].sum = sgt[t*2 + 1].sum + sgt[t*2 + 2].sum;
    }
}

/// -1 if not exist
int first_true(int t, int l, int r, int ll, int rr) {
    push(t, l, r);
    if (!sgt[t].sum)
        return -1;
    if (r - l == 1)
        return l;
    int mid = (l+r)/2;
    int res = -1;
    if (res == -1 && ll < mid)
        res = first_true(t*2 + 1, l, mid, ll, rr);
    if (res == -1 && mid < rr)
        res = first_true(t*2 + 2, mid, r, ll, rr);
    return res;
}
/// -1 if not exist
int first_false(int t, int l, int r, int ll, int rr) {
    push(t, l, r);
    if (sgt[t].sum == (r-l))
        return -1;
    if (r - l == 1)
        return l;
    int mid = (l+r)/2;
    int res = -1;
    if (res == -1 && ll < mid)
        res = first_false(t*2 + 1, l, mid, ll, rr);
    if (res == -1 && mid < rr)
        res = first_false(t*2 + 2, mid, r, ll, rr);
    return res;
}

int main() {

    int n; scanf("%d", &n);

    while (n --> 0) {
        char ch[4];
        int bg;
        scanf("%s%d", ch, &bg);
        if (ch[0] == 'a') {
            int nd = first_false(0, 0, N, bg, N);
            //printf("[%d, %d)\n", bg, nd);
            set_val(0, 0, N, nd, 1);
            if (bg < nd)
                seg_set_val(0, 0, N, bg, nd, 0);
        } else {
            int nd = first_true(0, 0, N, bg, N);
            //printf("[%d, %d)\n", bg, nd);
            set_val(0, 0, N, nd, 0);
            if (bg < nd)
                seg_set_val(0, 0, N, bg, nd, 1);
        }
        push(0, 0, N);
        printf("%d\n", sgt[0].sum);
    }

    return 0;
}
